@@ -34,8 +34,10 @@ class CorpusMetric:
         self.entity_classification_report = entity_classification_report
 
     @classmethod
-    def create_from_corpus(cls, true, pred):
-        true, pred = cls._make_corpus_match(true, pred)
+    def create_from_corpus(cls, true, pred, skip_match=False):
+        if not skip_match:
+            true, pred = cls._make_corpus_match(true, pred)
+
         intent_confusion_matrix = cls._intent_confusion_matrix(true, pred)
         domain_confusion_matrix = cls._domain_confusion_matrix(true, pred)
         entity_f1_score = cls._entity_f1_score(true, pred)
