@@ -16,6 +16,7 @@ class CorpusStatistics:
         intent: Optional[Counter] = None,
         entity_types: Optional[Dict[str, Counter]] = None,
         entity_values: Optional[Dict[Tuple, Counter]] = None,
+        entity_count: Optional[Counter] = None,
         token_count=None,
         token_vocab=None,
     ):
@@ -25,6 +26,7 @@ class CorpusStatistics:
         self.intent: Optional[Counter] = intent
         self.entity_types: Optional[Dict[str, Counter]] = entity_types
         self.entity_values: Optional[Dict[Tuple, Counter]] = entity_values
+        self.entity_count: Optional[Counter] = entity_count
         self.token_count = token_count
         self.token_vocab = token_vocab
 
@@ -36,6 +38,7 @@ class CorpusStatistics:
         intent = cls._collect_intent(corpus)
         entity_types = cls._collect_entity_types(corpus)
         entity_values = cls._collect_entity_values(corpus)
+        entity_count = cls._collect_entity_count(corpus)
         token_count = cls._collect_token_count(corpus)
         token_vocab = cls._collect_token_vocab(corpus)
 
@@ -46,6 +49,7 @@ class CorpusStatistics:
             intent,
             entity_types,
             entity_values,
+            entity_count,
             token_count,
             token_vocab,
         )
@@ -92,6 +96,14 @@ class CorpusStatistics:
                 value_mapping[tuple(span.value)].append(span.entity)
         return {k: Counter(v) for k, v in value_mapping.items()}
 
+    @classmethod
+    def _collect_entity_count(cls, corpus) -> Counter:
+        entity_count_list = []
+        for doc in corpus:
+            entity_count_list.extend([span.entity for span in doc.span_set])
+
+        return Counter(entity_count_list)
+
     @classmethod
     def _collect_token_count(cls, corpus) -> Counter:
         token_count_list = []
